=================
How to Contribute
=================

This document is heavily based on
`Contributing to Open Source Projects <https://github.com/bitprophet/contribution-guide.org/blob/master/index.rst>`_


.. include:: submitting_bugs.rst


.. include:: contributing_changes.rst
